@@ -3,6 +3,7 @@
 import os
 
 import anyconfig
+import jsonschema.exceptions
 import pathspec
 from appdirs import AppDirs
 from jsonschema._utils import format_as_index
@@ -44,8 +45,8 @@ class Settings(object):
         defaults = self._get_defaults()
         self.config_file = args.get("config_file") or default_config_file
 
-        args.pop("config_file", None)
         tmp_args = dict(filter(lambda item: item[1] is not None, args.items()))
+        tmp_args.pop("config_file", None)
 
         tmp_dict = {}
         for key, value in tmp_args.items():
@@ -101,17 +102,27 @@ class Settings(object):
             if f not in defaults["ansible"]["custom_modules"]:
                 defaults["ansible"]["custom_modules"].append(f)
 
+        if defaults["rules"]["buildin"]:
+            defaults["rules"]["standards"].append(
+                os.path.join(resource_filename("ansiblelater", "rules"))
+            )
+
+        defaults["rules"]["standards"] = [
+            os.path.relpath(os.path.normpath(p)) for p in defaults["rules"]["standards"]
+        ]
+
         return defaults
 
     def _get_defaults(self):
-        rules_dir = os.path.join(resource_filename("ansiblelater", "data"))
         defaults = {
             "rules": {
-                "standards": rules_dir,
+                "buildin": True,
+                "standards": [],
                 "filter": [],
                 "exclude_filter": [],
                 "ignore_dotfiles": True,
-                "exclude_files": []
+                "exclude_files": [],
+                "version": ""
             },
             "logging": {
                 "level": "WARNING",
@@ -159,8 +170,11 @@ class Settings(object):
         try:
             anyconfig.validate(config, self.schema, ac_schema_safe=False)
             return True
-        except Exception as e:
-            schema_error = "Failed validating '{validator}' in schema{schema}".format(
+        except jsonschema.exceptions.ValidationError as e:
+            schema_error = (
+                "Error while loading configuration:\n"
+                "Failed validating '{validator}' in schema{schema}"
+            ).format(
                 validator=e.validator, schema=format_as_index(list(e.relative_schema_path)[:-1])
             )
             utils.sysexit_with_message(
