@@ -531,7 +531,11 @@ def parse_yaml_linenumbers(data, filename):
         return node
 
     def construct_mapping(node, deep=False):
-        mapping = AnsibleConstructor.construct_mapping(loader, node, deep=deep)
+        try:
+            mapping = AnsibleConstructor.construct_mapping(loader, node, deep=deep)
+        except yaml.constructor.ConstructorError as e:
+            raise LaterError("syntax error", e)
+
         if hasattr(node, "__line__"):
             mapping[LINE_NUMBER_KEY] = node.__line__
         else:
@@ -544,7 +548,7 @@ def parse_yaml_linenumbers(data, filename):
         loader = AnsibleLoader(data, **kwargs)
         loader.compose_node = compose_node
         loader.construct_mapping = construct_mapping
-        data = loader.get_single_data()
+        data = loader.get_single_data() or []
     except (yaml.parser.ParserError, yaml.scanner.ScannerError) as e:
         raise LaterError("syntax error", e)
     except (yaml.composer.ComposerError) as e:
@@ -576,3 +580,29 @@ def normalized_yaml(file, options):
     except (yaml.parser.ParserError, yaml.scanner.ScannerError) as e:
         raise LaterError("syntax error", e)
     return lines
+
+
+class UnsafeTag:
+    """Handle custom yaml unsafe tag."""
+
+    yaml_tag = u"!unsafe"
+
+    def __init__(self, value):
+        self.unsafe = value
+
+    @staticmethod
+    def yaml_constructor(loader, node):
+        return loader.construct_scalar(node)
+
+
+class VaultTag:
+    """Handle custom yaml vault tag."""
+
+    yaml_tag = u"!vault"
+
+    def __init__(self, value):
+        self.unsafe = value
+
+    @staticmethod
+    def yaml_constructor(loader, node):
+        return loader.construct_scalar(node)
